@@ -1,7 +1,7 @@
 from .betweenness import *
 from .betweenness_subset import *
 from .closeness import *
-from .communicability_alg import *
+from .subgraph_alg import *
 from .current_flow_closeness import *
 from .current_flow_betweenness import *
 from .current_flow_betweenness_subset import *
@@ -11,3 +11,6 @@ from .eigenvector import *
 from .harmonic import *
 from .katz import *
 from .load import *
+from .reaching import *
+from .percolation import *
+from .second_order import *
