@@ -42,8 +42,8 @@ class TestFunction(object):
                      sorted(nx.degree(self.DG, weight='weight')))
 
     def test_neighbors(self):
-        assert_equal(self.G.neighbors(1), nx.neighbors(self.G, 1))
-        assert_equal(self.DG.neighbors(1), nx.neighbors(self.DG, 1))
+        assert_equal(list(self.G.neighbors(1)), list(nx.neighbors(self.G, 1)))
+        assert_equal(list(self.DG.neighbors(1)), list(nx.neighbors(self.DG, 1)))
 
     def test_number_of_nodes(self):
         assert_equal(self.G.number_of_nodes(), nx.number_of_nodes(self.G))
@@ -81,6 +81,42 @@ class TestFunction(object):
                             (13, 14, {'weight': 2.}),
                             (14, 15, {'weight': 2.})])
 
+        G = self.G.copy()
+        nlist = [None]
+        nx.add_path(G, nlist)
+        assert_edges_equal(G.edges(nlist), [])
+        assert_nodes_equal(G, list(self.G) + [None])
+
+        G = self.G.copy()
+        nlist = iter([None])
+        nx.add_path(G, nlist)
+        assert_edges_equal(G.edges([None]), [])
+        assert_nodes_equal(G, list(self.G) + [None])
+
+        G = self.G.copy()
+        nlist = [12]
+        nx.add_path(G, nlist)
+        assert_edges_equal(G.edges(nlist), [])
+        assert_nodes_equal(G, list(self.G) + [12])
+
+        G = self.G.copy()
+        nlist = iter([12])
+        nx.add_path(G, nlist)
+        assert_edges_equal(G.edges([12]), [])
+        assert_nodes_equal(G, list(self.G) + [12])
+
+        G = self.G.copy()
+        nlist = []
+        nx.add_path(G, nlist)
+        assert_edges_equal(G.edges, self.G.edges)
+        assert_nodes_equal(G, list(self.G))
+
+        G = self.G.copy()
+        nlist = iter([])
+        nx.add_path(G, nlist)
+        assert_edges_equal(G.edges, self.G.edges)
+        assert_nodes_equal(G, list(self.G))
+
     def test_add_cycle(self):
         G = self.G.copy()
         nlist = [12, 13, 14, 15]
@@ -212,7 +248,7 @@ class TestFunction(object):
 
         assert_raises(nx.NetworkXError, nx.info, G, n=-1)
 
-    def test_neighbors(self):
+    def test_neighbors_complete_graph(self):
         graph = nx.complete_graph(100)
         pop = random.sample(list(graph), 1)
         nbors = list(nx.neighbors(graph, pop[0]))
