@@ -17,14 +17,14 @@ nodes and (partially) duplicate their edges. These functions are
 generally inspired by biological networks.
 
 """
-import random
-
 import networkx as nx
+from networkx.utils import py_random_state
 from networkx.exception import NetworkXError
 
 __all__ = ['partial_duplication_graph', 'duplication_divergence_graph']
 
 
+@py_random_state(4)
 def partial_duplication_graph(N, n, p, q, seed=None):
     """Return a random graph using the partial duplication model.
 
@@ -45,8 +45,9 @@ def partial_duplication_graph(N, n, p, q, seed=None):
         The probability of joining the source node to the duplicate
         node. Must be a number in the between zero and one, inclusive.
 
-    seed : int, optional
-        Seed for random number generator (default=None).
+    seed : integer, random_state, or None (default)
+        Indicator of random number generation state.
+        See :ref:`Randomness<randomness>`.
 
     Notes
     -----
@@ -68,7 +69,7 @@ def partial_duplication_graph(N, n, p, q, seed=None):
     ----------
     .. [1] Knudsen Michael, and Carsten Wiuf. "A Markov chain approach to
            randomly grown graphs." Journal of Applied Mathematics 2008.
-           <https://dx.doi.org/10.1155/2008/190836>
+           <https://doi.org/10.1155/2008/190836>
 
     """
     if p < 0 or p > 1 or q < 0 or q > 1:
@@ -76,8 +77,6 @@ def partial_duplication_graph(N, n, p, q, seed=None):
         raise NetworkXError(msg)
     if n > N:
         raise NetworkXError("partial duplication graph must have n <= N.")
-    if seed is not None:
-        random.seed(seed)
 
     G = nx.complete_graph(n)
     for new_node in range(n, N):
@@ -85,20 +84,21 @@ def partial_duplication_graph(N, n, p, q, seed=None):
         G.add_node(new_node)
 
         # Pick a random vertex, u, already in the graph.
-        src_node = random.randint(0, new_node)
+        src_node = seed.randint(0, new_node)
 
         # Join v and u with probability q.
-        if random.random() < q:
+        if seed.random() < q:
             G.add_edge(new_node, src_node)
 
         # For each neighbor of u...
         for neighbor_node in list(nx.all_neighbors(G, src_node)):
             # Add the neighbor to v with probability p.
-            if random.random() < p:
+            if seed.random() < p:
                 G.add_edge(new_node, neighbor_node)
     return G
 
 
+@py_random_state(2)
 def duplication_divergence_graph(n, p, seed=None):
     """Returns an undirected graph using the duplication-divergence model.
 
@@ -112,8 +112,9 @@ def duplication_divergence_graph(n, p, seed=None):
         The desired number of nodes in the graph.
     p : float
         The probability for retaining the edge of the replicated node.
-    seed : int, optional
-        A seed for the random number generator of :mod:`random` (default=None).
+    seed : integer, random_state, or None (default)
+        Indicator of random number generation state.
+        See :ref:`Randomness<randomness>`.
 
     Returns
     -------
@@ -145,8 +146,6 @@ def duplication_divergence_graph(n, p, seed=None):
     if n < 2:
         msg = 'n must be greater than or equal to 2'
         raise nx.NetworkXError(msg)
-    if seed is not None:
-        random.seed(seed)
 
     G = nx.Graph()
 
@@ -155,13 +154,13 @@ def duplication_divergence_graph(n, p, seed=None):
     i = 2
     while i < n:
         # Choose a random node from current graph to duplicate.
-        random_node = random.choice(list(G))
+        random_node = seed.choice(list(G))
         # Make the replica.
         G.add_node(i)
         # flag indicates whether at least one edge is connected on the replica.
         flag = False
         for nbr in G.neighbors(random_node):
-            if random.random() < p:
+            if seed.random() < p:
                 # Link retention step.
                 G.add_edge(i, nbr)
                 flag = True
