@@ -25,7 +25,7 @@ adjacency list (anything following the # in a line is a comment)::
 __author__ = '\n'.join(['Aric Hagberg <hagberg@lanl.gov>',
                         'Dan Schult <dschult@colgate.edu>',
                         'Loïc Séguin-C. <loicseguin@gmail.com>'])
-#    Copyright (C) 2004-2017 by
+#    Copyright (C) 2004-2018 by
 #    Aric Hagberg <hagberg@lanl.gov>
 #    Dan Schult <dschult@colgate.edu>
 #    Pieter Swart <swart@lanl.gov>
@@ -154,8 +154,8 @@ def parse_adjlist(lines, comments='#', delimiter=None,
     lines : list or iterator of strings
         Input data in adjlist format
 
-    create_using: NetworkX graph container
-       Use given NetworkX graph for holding nodes or edges.
+    create_using : NetworkX graph constructor, optional (default=nx.Graph)
+       Graph type to create. If graph instance, then cleared before populated.
 
     nodetype : Python type, optional
        Convert nodes to this type.
@@ -191,15 +191,7 @@ def parse_adjlist(lines, comments='#', delimiter=None,
     read_adjlist
 
     """
-    if create_using is None:
-        G = nx.Graph()
-    else:
-        try:
-            G = create_using
-            G.clear()
-        except:
-            raise TypeError("Input graph is not a NetworkX graph type")
-
+    G = nx.empty_graph(0, create_using)
     for line in lines:
         p = line.find(comments)
         if p >= 0:
@@ -237,8 +229,8 @@ def read_adjlist(path, comments="#", delimiter=None, create_using=None,
        Filename or file handle to read.
        Filenames ending in .gz or .bz2 will be uncompressed.
 
-    create_using: NetworkX graph container
-       Use given NetworkX graph for holding nodes or edges.
+    create_using : NetworkX graph constructor, optional (default=nx.Graph)
+       Graph type to create. If graph instance, then cleared before populated.
 
     nodetype : Python type, optional
        Convert nodes to this type.
@@ -282,11 +274,11 @@ def read_adjlist(path, comments="#", delimiter=None, create_using=None,
     Since nodes must be hashable, the function nodetype must return hashable
     types (e.g. int, float, str, frozenset - or tuples of those, etc.)
 
-    The optional create_using parameter is a NetworkX graph container.
-    The default is Graph(), an undirected graph.  To read the data as
-    a directed graph use
+    The optional create_using parameter indicates the type of NetworkX graph
+    created.  The default is `nx.Graph`, an undirected graph.
+    To read the data as a directed graph use
 
-    >>> G=nx.read_adjlist("test.adjlist", create_using=nx.DiGraph())
+    >>> G=nx.read_adjlist("test.adjlist", create_using=nx.DiGraph)
 
     Notes
     -----
