@@ -7,18 +7,18 @@ Do not add this file to the repository.
 
 import datetime
 
-version = '2.1'
-date = 'Tue Aug  7 15:45:58 2018'
+version = '2.2'
+date = 'Wed Sep 26 12:42:48 2018'
 
 # Was NetworkX built from a development version? If so, remember that the major
 # and minor versions reference the "target" (rather than "current") release.
 dev = False
 
 # Format: (name, major, min, revision)
-version_info = ('networkx', '2', '1', None)
+version_info = ('networkx', '2', '2', None)
 
 # Format: a 'datetime.datetime' instance
-date_info = datetime.datetime(2018, 8, 7, 15, 45, 58)
+date_info = datetime.datetime(2018, 9, 26, 12, 42, 48)
 
 # Format: (vcs, vcs_tuple)
 vcs_info = (None, (None, None))
